exceptiontools.VoiceContainmentError
====================================

.. abjad-lineage:: abjad.tools.exceptiontools.VoiceContainmentError.VoiceContainmentError

.. autoclass:: abjad.tools.exceptiontools.VoiceContainmentError.VoiceContainmentError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.VoiceContainmentError.VoiceContainmentError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.VoiceContainmentError.VoiceContainmentError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.VoiceContainmentError.VoiceContainmentError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.VoiceContainmentError.VoiceContainmentError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.VoiceContainmentError.VoiceContainmentError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.VoiceContainmentError.VoiceContainmentError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.VoiceContainmentError.VoiceContainmentError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.VoiceContainmentError.VoiceContainmentError.__unicode__
   :noindex:
